import requests
__version__ = "0.1.4"
__author__ = 'Yair Koskas'
def greet():
    print('Hello, i\'m koskas and this is my python package!')
def joke():
    r = requests.get('http://api.icndb.com/jokes/random')
    s = r.text.encode('utf-8').decode()
    s = s.replace('&quot;','"')
    print(s[s.find('joke')+8:s.rfind('.')])
def isprime(n):
    for i in range(math.ceil(math.sqrt(n))):
        if n%i == 0:
            return False
    return False



from setuptools import setup

setup(
    name='koskas',
    version='0.1.4',    
    description='My python package',
    scripts=['joke'],
    url='https://github.com/yairKoskas/koskas',
    author='Yair Koskas',
    author_email='yairi2003@gmail.com',
    license='BSD 2-clause',
    packages=['koskas'],
    install_requires=['requests'],
    classifiers=[
        'Development Status :: 1 - Planning',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: BSD License',  
        'Operating System :: POSIX :: Linux',        
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 3',
    ],
)
